@@ -1,5 +1,6 @@
 from .dssclient import DSSClient
-from .fmclient import FMClientAWS, FMClientAzure
+from .fmclient import FMClientAWS, FMClientAzure, FMClientGCP
+from .govern_client import GovernClient
 
 from .apinode_client import APINodeClient
 from .apinode_admin_client import APINodeAdminClient
