@@ -36,3 +36,9 @@ class APINodeAdminClient(DSSBaseClient):
 
     def get_metrics(self):
         return self._perform_json("GET", "metrics")
+
+    def import_code_env_in_cache(self, file_dir, language):
+        self._perform_empty("POST", "cached-code-envs", params={
+            "fileDir": file_dir,
+            "language": language
+        })
