@@ -93,6 +93,43 @@ class APINodeClient(DSSBaseClient):
 
         return self._perform_json("POST", "%s/predict-multi" % endpoint_id, body = obj)
 
+    def forecast(self, endpoint_id, records, forced_generation=None, dispatch_key=None):
+        """
+        Forecast using a time series forecasting model on a DSS API node endpoint
+
+        :param str endpoint_id: Identifier of the endpoint to query
+        :param records: List of time series data records to be used as an input for the
+                        time series forecasting model. Each record should be a dict where
+                        keys are feature names, and values feature values.
+                        Example: records = [
+                            {'date': '2015-01-04T00:00:00.000Z', 'timeseries_id': 'A', 'target': 10.0},
+                            {'date': '2015-01-04T00:00:00.000Z', 'timeseries_id': 'B', 'target': 4.5},
+                            {'date': '2015-01-05T00:00:00.000Z', 'timeseries_id': 'A', 'target': 2.0},
+                            ...,
+                            {'date': '2015-03-20T00:00:00.000Z', 'timeseries_id': 'B', 'target': 1.3}
+                        ]
+        :param forced_generation: See documentation about multi-version prediction
+        :param dispatch_key: See documentation about multi-version prediction
+
+        :return: a Python dict of the API answer. The answer contains a "results" key
+                 (which is an array of result objects, corresponding to the forecast records)
+                 Example: {'results': [
+                            {'forecast': 12.57, 'ignored': False, 'quantiles': [0.0001, 0.5, 0.9999], 'quantilesValues': [3.0, 16.0, 16.0],
+                              'time': '2015-03-21T00:00:00.000000Z', 'timeseriesIdentifier': {'timeseries_id': 'A'}},
+                            {'forecast': 15.57, 'ignored': False, 'quantiles': [0.0001, 0.5, 0.9999], 'quantilesValues': [3.0, 18.0, 19.0],
+                              'time': '2015-03-21T00:00:00.000000Z', 'timeseriesIdentifier': {'timeseries_id': 'B'}},
+                          ...], ...}
+        """
+
+        obj = {"items": records}
+
+        if forced_generation is not None:
+            obj["dispatch"] = {"forcedGeneration": forced_generation}
+        elif dispatch_key is not None:
+            obj["dispatch"] = {"dispatchKey": dispatch_key}
+
+        return self._perform_json("POST", "{}/forecast".format(endpoint_id), body=obj)
+
     def sql_query(self, endpoint_id, parameters):
         """
         Queries a "SQL query" endpoint on a DSS API node
